# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.26.0~6fb9cb8',
    built_at='2026-01-06 12:19:51Z',
    sha='6fb9cb8a23068c7f699e72b0d22ff975db2ead69',
    branch='HEAD',
    tag='v4.26.0',
)
